@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -44,27 +46,14 @@ BatchGetRecordErrorTypeDef = TypedDict(
     },
 )
 
-_RequiredBatchGetRecordIdentifierTypeDef = TypedDict(
-    "_RequiredBatchGetRecordIdentifierTypeDef",
+BatchGetRecordIdentifierTypeDef = TypedDict(
+    "BatchGetRecordIdentifierTypeDef",
     {
         "FeatureGroupName": str,
         "RecordIdentifiersValueAsString": Sequence[str],
+        "FeatureNames": NotRequired[Sequence[str]],
     },
 )
-_OptionalBatchGetRecordIdentifierTypeDef = TypedDict(
-    "_OptionalBatchGetRecordIdentifierTypeDef",
-    {
-        "FeatureNames": Sequence[str],
-    },
-    total=False,
-)
-
-
-class BatchGetRecordIdentifierTypeDef(
-    _RequiredBatchGetRecordIdentifierTypeDef, _OptionalBatchGetRecordIdentifierTypeDef
-):
-    pass
-
 
 BatchGetRecordRequestRequestTypeDef = TypedDict(
     "BatchGetRecordRequestRequestTypeDef",
@@ -109,27 +98,14 @@ FeatureValueTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRecordRequestRequestTypeDef = TypedDict(
-    "_RequiredGetRecordRequestRequestTypeDef",
+GetRecordRequestRequestTypeDef = TypedDict(
+    "GetRecordRequestRequestTypeDef",
     {
         "FeatureGroupName": str,
         "RecordIdentifierValueAsString": str,
+        "FeatureNames": NotRequired[Sequence[str]],
     },
 )
-_OptionalGetRecordRequestRequestTypeDef = TypedDict(
-    "_OptionalGetRecordRequestRequestTypeDef",
-    {
-        "FeatureNames": Sequence[str],
-    },
-    total=False,
-)
-
-
-class GetRecordRequestRequestTypeDef(
-    _RequiredGetRecordRequestRequestTypeDef, _OptionalGetRecordRequestRequestTypeDef
-):
-    pass
-
 
 GetRecordResponseTypeDef = TypedDict(
     "GetRecordResponseTypeDef",
